==> nlp-2.2.tar.gz: nlp-2.2/src/modMain.pl <==
##
##  modMain -- Main procedure
##

package Main;

#
#   global usage
#
sub usage {
    $printer = "UNKNOWN";
    if ($ENV{'PRINTER'} ne '') {
       $printer = $ENV{'PRINTER'};
    }
print STDERR <<"EOT"
Usage: $prgname [options] file [[options} file] ...

 ASCII to Postscript Options:         Output Options:                 
 F #  fontsize in points              c #  print multiple copies (def: 1)
 B    use bold font                   p    preview output before printing
 t #  tabindent (def: 8)            P,d s  select printer (def: $printer) 
 w    wrap/fold lines if too long     o s  write to file instead of printer
 l #  lines per page (adj.fontsize)                                        
 N    line-numbers                    Printer Options:            
 H s  page header                     D    force duplex  mode
 m    interpret metachars TAB,BS,FF   S    force simplex mode 
                                      T #  select papertray 
 DVI to Postscript Options:           M    manual paper input
 R #  resolution in DPI (def: 300)   
                                      Special Command Options:               
 Common Layout Options:               q    display queue of specific printer 
 L    landscape mode (def: portrait)  Q    display queue of all printers     
 2    two pages on one physical       i    information about specific printer
 4    four pages on one physical      I    information about all printers    
 s r  print only selected pages       n    notify admin about printer trouble
 b    draw surrounding borders        h    this page                         
                                      V    version information  
 #=number
 f=file                               General Processing Options:
 s=string                             v    verbose mode          
 r=range (#,-#,#-,#-#,r,o,e,B)        e    expert mode           
                                      x    debug mode            
EOT
}


sub Main {
    #   get dirname and basename of program
    $prgpath = $0;
    if ($prgpath =~ m|^[^/]+$|) {
        $prgpath = ".";
    }
    else {
        $prgpath =~ s|^(.*)/[^/]+$|$1|;
    }
    $prgname = $0;
    $prgname =~ s|^.*/([^/]+)$|$1|;
    
    #   common definitions
    $tmpdir = "/tmp";

    #  prepend the argline with contents of NLPOPTS
    if ($ENV{'NLPOPTS'} ne '') {
        @ARGVN = split(' ', $ENV{'NLPOPTS'});
        foreach $opt (@ARGV) {
            push(@ARGVN, $opt);
        }
        @ARGV = @ARGVN;
    }

    #   argument line parsing
    %optiondecl = (
        'fontsize',      "F: unset",
        'boldface',      "B  false",
        'borders',       "b  false",
        'tabindent',     "t: 8",
        'wraplines',     "w  false",
        'maxlines',      "l: unset",
        'linenumbers',   "N  false",
        'pageheader',    "H: unset",
        'metachars',     "m  false",
        'dpi',           "R: 300",
        'landscapemode', "L  false",
        '2page',         "2  false",
        '4page',         "4  false",
        'selectpage',    "s: unset",
        'copies',        "c: 1",
        'preview',       "p  false",
        'printer',       "P: unset",
        'printerd',      "d: unset",
        'outputfile',    "o: unset",
        'duplexmode',    "D  false",
        'simplexmode',   "S  false",
        'papertray',     "T: unset",
        'manualfeed',    "M  false",
        'queue',         "q  false",
        'queueall',      "Q  false",
        'info',          "i  false",
        'infoall',       "I  false",
        'notify',        "n  false",
        'help',          "h  false",
        'version',       "V  false",
        'debug',         "x  false",
        'verbose',       "v  false",
        'expert',        "e  false"
    );
    $optionlist = '';
    foreach $val (values(%optiondecl)) {
        $val =~ m|^([a-zA-Z0-9][:+]?).*|;
        $optionlist = $optionlist . $1;
    }

    if ($#ARGV eq -1) {
        &usage;
        exit $Util::EX{'OK'};
    }

    %option = %optiondecl;

    &Cap::LoadCap("${Config::libdir}/printer.cap");

    $cnt = 0;
    while ($#ARGV >= 0) {
        $cnt++;

        ($rc, @ARGV) = &Getopts::Getopts($optionlist, @ARGV);
        if ($rc == 0) {
            print STDERR "Type '$prgname -h' for usage.\n";
            exit $Util::EX{'USAGE'};
        }

        foreach $optname (keys(%optiondecl)) {
            $optchar = $optiondecl{$optname};
            $optchar =~ m|^([a-zA-Z0-9])([:+]?)[ \t]+(.+)|;
            ($optchar, $optcharCard, $optdef) = ($1, $2, $3);
            eval "\$optval = \$Getopts::opt_$optchar;";
            if ($optval ne '') {
                if ($optcharCard eq ':') {
                    $option{$optname} = $optval;
                }
                else {
                    $option{$optname} = ($optval == 0 ? "false" : "true");
                }
            }
            else {
                $option{$optname} = $optdef;
            }
        }

        #  special commands are processed at any time
        if ($option{'help'} eq 'true') {
            &usage;
            exit $Util::EX{'OK'};
        }
        if ($option{'version'} eq 'true') {
            print STDERR "$Vers::Hello\n";
            print STDERR "    [$Config::target]\n";
            print STDERR "\n";
            print STDERR "Copyright (c) 1992, 1993\n";
            print STDERR "    software design & management (sd&m) GmbH & Co KG,\n";
            print STDERR "    All Rights Reserved.\n";
            print STDERR "Copyright (c) 1995\n";
            print STDERR "    Technische Universitaet Muenchen (TUM),\n";
            print STDERR "    All Rights Reserved.\n";
            print STDERR "Copyright (c) 1992, 1993, 1994, 1995\n";
            print STDERR "    Ralf S. Engelschall,\n";
            print STDERR "    All Rights Reserved.\n";
            exit $Util::EX{'OK'};
        }
        if ($option{'queueall'} eq 'true') {
            &Queue::queueall(*option);
            exit $Util::EX{'OK'};
        }
        if ($option{'infoall'} eq 'true') {
            &Info::infoall(*option);
            exit $Util::EX{'OK'};
        }

        if ($option{'printer'} eq 'unset' && $option{'printerd'} ne 'unset') {
            $option{'printer'} = $option{'printerd'};
        }
        if ($option{'printer'} eq 'unset' && $ENV{'PRINTER'} ne '') {
            $option{'printer'} = $ENV{'PRINTER'};
        }
        if ($option{'printer'} eq 'unset' && $option{'outputfile'} eq 'unset') {
            print STDERR "*** Sorry, you must provide me with a destination printer\n";
            print STDERR "*** by at least having either a PRINTER env-variable or\n";
            print STDERR "*** specifing a explicit printer via -P or -d option!\n";
            exit $Util::EX{'FAIL'};
        }

        if ($option{'queue'} eq 'true') {
            &Queue::queue(*option);
            exit $Util::EX{'OK'};
        }
        if ($option{'info'} eq 'true') {
            &Info::info(*option);
            exit $Util::EX{'OK'};
        }
        if ($option{'notify'} eq 'true') {
            &Notify::notify(*option);
            exit $Util::EX{'OK'};
        }

        if ($#ARGV == -1) {
            print STDERR "*** you have to specify at least one file to print\n";
            exit $Util::EX{'FAIL'};

        }
        @files = ();
        while ($#ARGV >= 0 && $ARGV[0] !~ m|^-.|) {
            push(@files, $ARGV[0]);
            shift(@ARGV);
        }

        eval "\%option${cnt} = \%option;";
        eval "push(\@OPTIONPTR, \*option${cnt});";
        eval "\@files${cnt} = \@files;";
        eval "push(\@FILESPTR, \*files${cnt});";
        
    }

    #
    #  print it!
    #
    for ($j = 0; $j < $cnt; $j++) {
        *option = $OPTIONPTR[$j];
        *files  = $FILESPTR[$j];
        &Print::print(*option, *files);
    }
}

1;

==> nlp-2.7.tar.gz: nlp-2.7/src/modMain.pl <==
##
##  modMain.pl -- Main procedure
##  Copyright (c) Ralf S. Engelschall, All Rights Reserved.
##

package Main;

#
#   global usage
#
sub usage {
    $printer = "UNKNOWN";
    if ($ENV{'PRINTER'} ne '') {
       $printer = $ENV{'PRINTER'};
    }
print STDERR <<"EOT"
Usage: $prgname [options] file [[options} file] ...

 ASCII to Postscript Options:         Output Options:                 
 F #  fontsize in points              c #  print multiple copies (def: 1)
 B    use bold font                   p    preview output before printing
 t #  tabindent (def: 8)            P,d s  select printer (def: $printer) 
 w    wrap/fold lines if too long     o s  write to file instead of printer
 l #  lines per page (adj.fontsize)                                        
 N    line-numbers                    Printer Options:            
 H s  page header                     D    force duplex  mode
 m    visualize metachars TAB,BS,FF   S    force simplex mode 
                                      T #  select papertray 
 DVI to Postscript Options:           M    manual paper input
 R #  resolution in DPI (def: 300)   
                                      Special Command Options:               
 Common Layout Options:               q    display queue of specific printer 
 L    landscape mode (def: portrait)  Q    display queue of all printers     
 2    two pages on one physical       i    information about specific printer
 4    four pages on one physical      I    information about all printers    
 s r  print only selected pages       n    notify admin about printer trouble
 b    draw surrounding borders        h    this page                         
                                      V    version information  
 #=number
 f=file                               General Processing Options:
 s=string                             v    verbose mode          
 r=range (#,-#,#-,#-#,r,o,e,S,B)      e    expert mode           
                                      x    debug mode            
EOT
}


sub Main {
    #   get dirname and basename of program
    $prgpath = $0;
    if ($prgpath =~ m|^[^/]+$|) {
        $prgpath = ".";
    }
    else {
        $prgpath =~ s|^(.*)/[^/]+$|$1|;
    }
    $prgname = $0;
    $prgname =~ s|^.*/([^/]+)$|$1|;
    
    #   common definitions
    $tmpdir = "/tmp";

    #  prepend the argline with contents of NLPOPTS
    if ($ENV{'NLPOPTS'} ne '') {
        @ARGVN = split(' ', $ENV{'NLPOPTS'});
        foreach $opt (@ARGV) {
            push(@ARGVN, $opt);
        }
        @ARGV = @ARGVN;
    }

    #   argument line parsing
    %optiondecl = (
        'fontsize',      "F: unset",
        'boldface',      "B  false",
        'borders',       "b  false",
        'tabindent',     "t: 8",
        'wraplines',     "w  false",
        'maxlines',      "l: unset",
        'linenumbers',   "N  false",
        'pageheader',    "H: unset",
        'metachars',     "m  false",
        'dpi',           "R: 300",
        'landscapemode', "L  false",
        '2page',         "2  false",
        '4page',         "4  false",
        'selectpage',    "s: unset",
        'copies',        "c: 1",
        'preview',       "p  false",
        'printer',       "P: unset",
        'printerd',      "d: unset",
        'outputfile',    "o: unset",
        'duplexmode',    "D  false",
        'simplexmode',   "S  false",
        'papertray',     "T: unset",
        'manualfeed',    "M  false",
        'queue',         "q  false",
        'queueall',      "Q  false",
        'info',          "i  false",
        'infoall',       "I  false",
        'notify',        "n  false",
        'help',          "h  false",
        'version',       "V  false",
        'debug',         "x  false",
        'verbose',       "v  false",
        'expert',        "e  false"
    );
    $optionlist = '';
    foreach $val (values(%optiondecl)) {
        $val =~ m|^([a-zA-Z0-9][:+]?).*|;
        $optionlist = $optionlist . $1;
    }

    if ($#ARGV eq -1) {
        &usage;
        exit $Util::EX{'OK'};
    }

    %option = %optiondecl;

    &Cap::LoadCap("${Config::libdir}/printer.cap");

    $cnt = 0;
    while ($#ARGV >= 0) {
        $cnt++;

        ($rc, @ARGV) = &Getopts::Getopts($optionlist, @ARGV);
        if ($rc == 0) {
            print STDERR "Type '$prgname -h' for usage.\n";
            exit $Util::EX{'USAGE'};
        }

        foreach $optname (keys(%optiondecl)) {
            $optchar = $optiondecl{$optname};
            $optchar =~ m|^([a-zA-Z0-9])([:+]?)[ \t]+(.+)|;
            ($optchar, $optcharCard, $optdef) = ($1, $2, $3);
            eval "\$optval = \$Getopts::opt_$optchar;";
            if ($optval ne '') {
                if ($optcharCard eq ':') {
                    $option{$optname} = $optval;
                }
                else {
                    $option{$optname} = ($optval == 0 ? "false" : "true");
                }
            }
            else {
                $option{$optname} = $optdef;
            }
        }

        #  special commands are processed at any time
        if ($option{'help'} eq 'true') {
            &usage;
            exit $Util::EX{'OK'};
        }
        if ($option{'version'} eq 'true') {
            print STDERR "$Vers::Hello\n";
            print STDERR "    [$Config::target]\n";
            print STDERR "\n";
            print STDERR "Copyright (c) 1992, 1993 [only version 1]\n";
            print STDERR "    software design & management (sd&m) GmbH & Co KG,\n";
            print STDERR "    All Rights Reserved.\n";
            print STDERR "Copyright (c) 1995\n";
            print STDERR "    Technische Universitaet Muenchen (TUM),\n";
            print STDERR "    All Rights Reserved.\n";
            print STDERR "Copyright (c) 1992, 1993, 1994, 1995, 1996\n";
            print STDERR "    Ralf S. Engelschall,\n";
            print STDERR "    All Rights Reserved.\n";
            exit $Util::EX{'OK'};
        }
        if ($option{'queueall'} eq 'true') {
            &Queue::queueall(*option);
            exit $Util::EX{'OK'};
        }
        if ($option{'infoall'} eq 'true') {
            &Info::infoall(*option);
            exit $Util::EX{'OK'};
        }

        if ($option{'printer'} eq 'unset' && $option{'printerd'} ne 'unset') {
            $option{'printer'} = $option{'printerd'};
        }
        if ($option{'printer'} eq 'unset' && $ENV{'PRINTER'} ne '') {
            $option{'printer'} = $ENV{'PRINTER'};
        }
        if ($option{'printer'} eq 'unset' && $option{'outputfile'} eq 'unset') {
            print STDERR "*** Sorry, you must provide me with a destination printer\n";
            print STDERR "*** by at least having either a PRINTER env-variable or\n";
            print STDERR "*** specifing a explicit printer via -P or -d option!\n";
            exit $Util::EX{'FAIL'};
        }

        if ($option{'queue'} eq 'true') {
            &Queue::queue(*option);
            exit $Util::EX{'OK'};
        }
        if ($option{'info'} eq 'true') {
            &Info::info(*option);
            exit $Util::EX{'OK'};
        }
        if ($option{'notify'} eq 'true') {
            &Notify::notify(*option);
            exit $Util::EX{'OK'};
        }

        if ($#ARGV == -1) {
            print STDERR "*** you have to specify at least one file to print\n";
            exit $Util::EX{'FAIL'};

        }
        @files = ();
        while ($#ARGV >= 0 && $ARGV[0] !~ m|^-.|) {
            push(@files, $ARGV[0]);
            shift(@ARGV);
        }

        eval "\%option${cnt} = \%option;";
        eval "push(\@OPTIONPTR, \*option${cnt});";
        eval "\@files${cnt} = \@files;";
        eval "push(\@FILESPTR, \*files${cnt});";
        
    }

    #
    #  print it!
    #
    for ($j = 0; $j < $cnt; $j++) {
        *option = $OPTIONPTR[$j];
        *files  = $FILESPTR[$j];
        &Print::print(*option, *files);
    }
}

1;

##EOF##
